#if !defined(AFX_SOCK_H__71E8C4E0_4AD4_11D5_B88F_00008659960F__INCLUDED_)
#define AFX_SOCK_H__71E8C4E0_4AD4_11D5_B88F_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Sock.h : wb_[ t@C
//

#include "WINSOCK2.H"

/////////////////////////////////////////////////////////////////////////////
// CSock R}h ^[Qbg

class CSock
{
// Agr[g
public:
	int Connect6(LPCTSTR server_name, LPCTSTR port);
	void DisConnect();
	int ReadLine(CString &out);
	int SockWrite(LPCTSTR buf, int len);
	int SockRead(char *buf, int len);
#ifndef _IPV6_
	int GetIP(LPCTSTR addr, LPCTSTR ip);
#endif

private:
	SOCKET m_sock;

// Iy[V
public:
	CSock();
	virtual ~CSock();

// I[o[Ch
public:
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂
	//{{AFX_VIRTUAL(CSock)
	//}}AFX_VIRTUAL

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CSock)
		//  - ClassWizard ͂̈ʒuɃo֐ǉ܂͍폜܂B
	//}}AFX_MSG

// Cve[V
protected:
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SOCK_H__71E8C4E0_4AD4_11D5_B88F_00008659960F__INCLUDED_)
